searchNodes=[{"doc":"Functions to introspect the Unicode Unihan character database.","ref":"Unicode.Unihan.html","title":"Unicode.Unihan","type":"module"},{"doc":"Filter the Unihan database returning selected codepoints. Arguments fun is a 1-arity function that is passed the attribute map for a given codepoint. if the function returns a truthy value then the codepoint is included in the returned data. If the return value is falsy then the codepoint is omitted from the returned list. Returns a map of the filtered codepoints mapped to their attributes. Example iex&gt; Unicode.Unihan . filter ( &amp; ( &amp;1 . kTotalStrokes [ :&quot;Hans&quot; ] &gt; 30 ) ) ...&gt; |&gt; Enum . count ( ) 238 iex&gt; Unicode.Unihan . filter ( &amp; ( &amp;1 . kTotalStrokes [ :&quot;Hans&quot; ] != &amp;1 . kTotalStrokes [ :&quot;Hant&quot; ] ) ) ...&gt; |&gt; Enum . count 3 iex&gt; Unicode.Unihan . filter ( &amp; ( &amp;1 [ :kGradeLevel ] &lt;= 6 ) ) ...&gt; |&gt; Enum . count 2632","ref":"Unicode.Unihan.html#filter/1","title":"Unicode.Unihan.filter/1","type":"function"},{"doc":"Load the unihan data into :persistent_term. This function will be called on the first access by Unicode.Unihan.unihan/1 but can be called on application load if required. First the existence of an erlang term format file of the unihan database is found. If so, it is loaded. If not (the first time the function is called), the file is generated and then loaded.","ref":"Unicode.Unihan.html#load_unihan/0","title":"Unicode.Unihan.load_unihan/0","type":"function"},{"doc":"Filter the Unihan database returning selected codepoints that are not rejected by the provided function. Arguments fun is a 1-arity function that is passed the attribute map for a given codepoint. if the function returns a falsy value then the codepoint is included in the returned data. If the return value is truthy then the codepoint is omitted from the returned list. Returns a map of the codepoints that are not rejected mapped to their attributes. Example iex&gt; Unicode.Unihan . reject ( &amp; ( &amp;1 . kTotalStrokes [ :&quot;Hans&quot; ] &gt; 30 ) ) ...&gt; |&gt; Enum . count ( ) 97822","ref":"Unicode.Unihan.html#reject/1","title":"Unicode.Unihan.reject/1","type":"function"},{"doc":"Takes an integer codepoint, a Unihan codepoint map, or list of maps and returns the grapheme (or list of graphemes) of the codepoint. Examples iex&gt; Unicode.Unihan . to_string ( 25342 ) &quot;拾&quot; iex&gt; Unicode.Unihan . unihan ( &quot;拾&quot; ) ...&gt; |&gt; Unicode.Unihan . to_string ( ) &quot;拾&quot;","ref":"Unicode.Unihan.html#to_string/1","title":"Unicode.Unihan.to_string/1","type":"function"},{"doc":"Returns the Unihan database metadata for a given codepoint. The codepoint can be expressed as an integer or a grapheme. Examples iex&gt; Unicode.Unihan . unihan ( 171339 ) %{ codepoint : 171339 , kCantonese : %{ coda : &quot;&quot; , final : &quot;u&quot; , jyutping : &quot;ju4&quot; , nucleus : &quot;u&quot; , onset : &quot;j&quot; , tone : &quot;4&quot; } , kDefinition : [ &quot;(J) nonstandard variant of 魚 U+9B5A, fish&quot; ] , kHanYu : %{ page : 4674 , position : 9 , virtual : false , volume : 7 } , kIRGHanyuDaZidian : %{ page : 4674 , position : 9 , virtual : false , volume : 7 } , kIRGKangXi : %{ page : 1465 , position : 1 , virtual : true } , kIRG_GSource : %{ mapping : [ &quot;74674.09&quot; ] , source : &quot;GHZ&quot; } , kIRG_TSource : %{ mapping : &quot;3043&quot; , source : &quot;T4&quot; } , kIRG_VSource : %{ mapping : &quot;29D4B&quot; , source : &quot;VN&quot; } , kJapaneseKun : [ &quot;UO&quot; , &quot;SAKANA&quot; , &quot;SUNADORU&quot; ] , kJapaneseOn : &quot;GYO&quot; , kKangXi : %{ page : 1465 , position : 1 , virtual : true } , kNelson : 692 , kPhonetic : %{ class : 1605 } , kRSAdobe_Japan1_6 : [ %{ cid : 13717 , code : &quot;C&quot; , kangxi : 195 , strokes_radical : 10 , strokes_residue : 0 } , %{ cid : 13718 , code : &quot;V&quot; , kangxi : 195 , strokes_radical : 10 , strokes_residue : 0 } ] , kRSKangXi : %{ radical : 195 , strokes : 0 } , kRSUnicode : %{ radical : 195 , simplified_radical : false , strokes : 0 } , kTotalStrokes : %{ Hans : 11 , Hant : 11 } } iex&gt; Unicode.Unihan . unihan ( &quot;㝰&quot; ) %{ codepoint : 14192 , kCangjie : [ &quot;J&quot; , &quot;H&quot; , &quot;U&quot; , &quot;S&quot; ] , kCantonese : %{ coda : &quot;n&quot; , final : &quot;in&quot; , jyutping : &quot;min4&quot; , nucleus : &quot;i&quot; , onset : &quot;m&quot; , tone : &quot;4&quot; } , kDefinition : [ &quot;unable to meet, empty room&quot; ] , kHanYu : %{ page : 957 , position : 3 , virtual : false , volume : 2 } , kHanyuPinyin : %{ location : [ %{ page : 20957 , position : 3 , virtual : false } ] , readings : [ &quot;mián&quot; ] } , kIRGHanyuDaZidian : %{ page : 957 , position : 3 , virtual : false , volume : 2 } , kIRGKangXi : %{ page : 293 , position : 1 , virtual : false } , kIRG_GSource : %{ mapping : [ &quot;3E3C&quot; ] , source : &quot;G5&quot; } , kIRG_KSource : %{ mapping : &quot;236A&quot; , source : &quot;K3&quot; } , kIRG_TSource : %{ mapping : &quot;5A7D&quot; , source : &quot;T4&quot; } , kKangXi : %{ page : 293 , position : 1 , virtual : false } , kMandarin : &quot;mián&quot; , kRSUnicode : %{ radical : 40 , simplified_radical : false , strokes : 15 } , kSBGY : %{ page : 135 , position : 35 } , kTotalStrokes : %{ Hans : 18 , Hant : 18 } }","ref":"Unicode.Unihan.html#unihan/1","title":"Unicode.Unihan.unihan/1","type":"function"},{"doc":"Returns the field information for the data in the Unihan database.","ref":"Unicode.Unihan.html#unihan_fields/0","title":"Unicode.Unihan.unihan_fields/0","type":"function"},{"doc":"Allow easy interconversion of keyboard input and character.","ref":"Unicode.Unihan.Cangjie.html","title":"Unicode.Unihan.Cangjie","type":"module"},{"doc":"Converts an alphabet keyboard input to the Chinese Cangjie part. Returns an OK tuple. ## Example iex&gt; Unicode.Unihan.Cangjie . cangjie ( &quot;U&quot; ) { :ok , &quot;山&quot; }","ref":"Unicode.Unihan.Cangjie.html#cangjie/1","title":"Unicode.Unihan.Cangjie.cangjie/1","type":"function"},{"doc":"Converts an alphabet keyboard input, or a list of alphabet keyboard inputs, to the Chinese Cangjie part. Throws exception if invalid input is supplied. ## Example iex&gt; Unicode.Unihan.Cangjie . cangjie! ( &quot;U&quot; ) &quot;山&quot; iex&gt; Unicode.Unihan.Cangjie . cangjie! ( [ &quot;U&quot; , &quot;J&quot; ] ) [ &quot;山&quot; , &quot;十&quot; ]","ref":"Unicode.Unihan.Cangjie.html#cangjie!/1","title":"Unicode.Unihan.Cangjie.cangjie!/1","type":"function"},{"doc":"","ref":"Unicode.Unihan.Cangjie.html#cangjies/0","title":"Unicode.Unihan.Cangjie.cangjies/0","type":"function"},{"doc":"Unicode.Unihan.Cantonese acts on pronunciations as a simple string (e.g., &quot;faan1&quot;, &quot;gwai3&quot;), and provides functions to decompose these into standard structs as well as checking their validity.","ref":"Unicode.Unihan.Cantonese.html","title":"Unicode.Unihan.Cantonese","type":"module"},{"doc":"Returns true if the jyutping is validly constructed. This does not state anything about their usage in the language. Examples iex&gt; Unicode.Unihan.Cantonese . is_valid? ( &quot;faan1&quot; ) true iex&gt; Unicode.Unihan.Cantonese . is_valid? ( &quot;m4&quot; ) true iex&gt; Unicode.Unihan.Cantonese . is_valid? ( &quot;lan1&quot; ) true iex&gt; Unicode.Unihan.Cantonese . is_valid? ( &quot;faaaan1&quot; ) false iex&gt; Unicode.Unihan.Cantonese . is_valid? ( &quot;faan7&quot; ) false iex&gt; Unicode.Unihan.Cantonese . is_valid? ( &quot;fn1&quot; ) false","ref":"Unicode.Unihan.Cantonese.html#is_valid?/1","title":"Unicode.Unihan.Cantonese.is_valid?/1","type":"function"},{"doc":"","ref":"Unicode.Unihan.Cantonese.html#jyutping_index/0","title":"Unicode.Unihan.Cantonese.jyutping_index/0","type":"function"},{"doc":"Returns a :ok tuple with a struct of the string containing the jyutping split into a map with onset, nucleus, coda, tone, final, and jyutping as keys. The collection of functions is generated at compile time, with one for each row representing a possible pronunciation. If the input does not match any of the exhaustive enumerations, it is invalid, and an error tuple is returned. Examples iex&gt; Unicode.Unihan.Cantonese . to_jyutping! ( &quot;haan1&quot; ) %{ onset : &quot;h&quot; , nucleus : &quot;aa&quot; , coda : &quot;n&quot; , tone : &quot;1&quot; , final : &quot;aan&quot; , jyutping : &quot;haan1&quot; } iex&gt; Unicode.Unihan.Cantonese . to_jyutping! ( &quot;ngaang6&quot; ) %{ onset : &quot;ng&quot; , nucleus : &quot;aa&quot; , coda : &quot;ng&quot; , tone : &quot;6&quot; , final : &quot;aang&quot; , jyutping : &quot;ngaang6&quot; } iex&gt; Unicode.Unihan.Cantonese . to_jyutping! ( &quot;m4&quot; ) %{ onset : &quot;&quot; , nucleus : &quot;m&quot; , coda : &quot;&quot; , tone : &quot;4&quot; , final : &quot;m&quot; , jyutping : &quot;m4&quot; } iex&gt; Unicode.Unihan.Cantonese . to_jyutping ( &quot;xxx&quot; ) { :error , &quot;Invalid jyutping. Found \\&quot; xxx \\&quot; &quot; } iex&gt; Unicode.Unihan.Cantonese . to_jyutping ( 999 ) { :error , &quot;to_jyutping/1 requires a string as input&quot; }","ref":"Unicode.Unihan.Cantonese.html#to_jyutping/1","title":"Unicode.Unihan.Cantonese.to_jyutping/1","type":"function"},{"doc":"","ref":"Unicode.Unihan.Cantonese.html#to_jyutping!/1","title":"Unicode.Unihan.Cantonese.to_jyutping!/1","type":"function"},{"doc":"Unicode.Unihan.Radical encapsulates the mapping from CJK radical numbers to characters.","ref":"Unicode.Unihan.Radical.html","title":"Unicode.Unihan.Radical","type":"module"},{"doc":"Filter the Unicode CJK radical database returning selected codepoints. Arguments fun is a 1-arity function that is passed the attribute map for a given codepoint. if the function returns a truthy value then the codepoint is included in the returned data. If the return value is falsy then the codepoint is omitted from the returned list. Returns a map of the filtered codepoints mapped to their attributes. Example iex&gt; Unicode.Unihan.Radical . filter ( &amp; ( &amp;1 [ :Hant ] [ :radical_number ] &lt; 5 ) ) ...&gt; |&gt; Enum . count ( ) 4","ref":"Unicode.Unihan.Radical.html#filter/1","title":"Unicode.Unihan.Radical.filter/1","type":"function"},{"doc":"Returns grapheme associated with the radical, as specified in the CJK Radicals file. Arguments index is the Unicode radical number (1..214), reported from various radical stroke properties such as kRSUnicode . an optional argument, which can be one of: :unified_ideograph (default) shows the grapheme in the (normal) CJK unified ideograph Unicode block (hexadecimal 4000--6000) :radical_character shows the grapheme in the special, contiguous KangXi Radical block (2F00--2FD5) :all returns the full map for the radical Examples iex&gt; Unicode.Unihan.Radical . radical ( 187 ) &quot;馬&quot; iex&gt; Unicode.Unihan.Radical . radical ( 187 , script : :Hans ) &quot;马&quot; iex&gt; Unicode.Unihan.Radical . radical ( 187 , script : :Hant , glyph : :radical_character ) &quot;⾺&quot; iex&gt; Unicode.Unihan.Radical . radical ( 187 ) == Unicode.Unihan.Radical . radical ( 187 , script : :Hant , glyph : :radical_character ) false iex&gt; Unicode.Unihan.Radical . radical ( 187 , :all ) %{ Hans : %{ radical_character : 12002 , radical_number : 187 , unified_ideograph : 39532 } , Hant : %{ radical_character : 12218 , radical_number : 187 , unified_ideograph : 39340 } } iex&gt; Unicode.Unihan.Radical . radical ( 999 ) { :error , &quot;Invalid radical number. Valid numbers are an integer in the range 1..214&quot; }","ref":"Unicode.Unihan.Radical.html#radical/2","title":"Unicode.Unihan.Radical.radical/2","type":"function"},{"doc":"","ref":"Unicode.Unihan.Radical.html#radicals/0","title":"Unicode.Unihan.Radical.radicals/0","type":"function"},{"doc":"Filter the Unicode CJK radical database returning selected codepoints that are not rejected by the provided function. Arguments fun is a 1-arity function that is passed the attribute map for a given codepoint. if the function returns a falsy value then the codepoint is included in the returned data. If the return value is truthy then the codepoint is omitted from the returned list. Returns a map of the codepoints that are not rejected mapped to their attributes. Example iex&gt; Unicode.Unihan.Radical . reject ( &amp; ( &amp;1 [ :Hant ] [ :radical_number ] &lt; 5 ) ) ...&gt; |&gt; Enum . count ( ) 210","ref":"Unicode.Unihan.Radical.html#reject/1","title":"Unicode.Unihan.Radical.reject/1","type":"function"},{"doc":"Functions to parse the Unicode Unihan database files.","ref":"Unicode.Unihan.Utils.html","title":"Unicode.Unihan.Utils","type":"module"},{"doc":"Parse the jyutping_index.csv file.","ref":"Unicode.Unihan.Utils.html#parse_cantonese/0","title":"Unicode.Unihan.Utils.parse_cantonese/0","type":"function"},{"doc":"Parse one Unicode Unihan file and return a mapping from codepoint to a map of metadata for that codepoint.","ref":"Unicode.Unihan.Utils.html#parse_file/2","title":"Unicode.Unihan.Utils.parse_file/2","type":"function"},{"doc":"Parse all Unicode Unihan files and return a mapping from codepoint to a map of metadata for that codepoint.","ref":"Unicode.Unihan.Utils.html#parse_files/0","title":"Unicode.Unihan.Utils.parse_files/0","type":"function"},{"doc":"Parse the cjk_radicals.txt file. There is one line per CJK radical number. Each line contains three fields, separated by a semicolon (';'). The first field is the CJK radical number. The second field is the CJK radical character. The third field is the CJK unified ideograph. Simplified radicals are represented by radical numbers with a trailing apostrophe ' .","ref":"Unicode.Unihan.Utils.html#parse_radicals/0","title":"Unicode.Unihan.Utils.parse_radicals/0","type":"function"},{"doc":"Returns a map of the field definitions for a Unihan codepoint.","ref":"Unicode.Unihan.Utils.html#unihan_fields/0","title":"Unicode.Unihan.Utils.unihan_fields/0","type":"function"},{"doc":"Functions to return information about Unicode Unihan codepoints.","ref":"readme.html","title":"Unicode Unihan","type":"extras"},{"doc":"The package can be installed by adding unicode_unihan to your list of dependencies in mix.exs : def deps do [ { :unicode_unihan , &quot;~&gt; 0.1&quot; } ] end The docs can be found at https://hexdocs.pm/unicode_unihan .","ref":"readme.html#installation","title":"Unicode Unihan - Installation","type":"extras"},{"doc":"See the guide to Unihan and Unihan introspection livebook.","ref":"readme.html#tutorial-livebooks","title":"Unicode Unihan - Tutorial livebooks","type":"extras"},{"doc":"Copyright 2023 Kip Cole (@kipcole9) &amp; Jon Chui (@jkwchui) Licensed under the Apache License, Version 2.0 (the &quot;License&quot;); you may not use this file except in compliance with the License. You may obtain a copy of the License at http :// www . apache . org / licenses / LICENSE - 2.0 Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an &quot;AS IS&quot; BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.","ref":"license.html","title":"License","type":"extras"},{"doc":"","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"This is the changelog for Unicode Unihan v0.3.0 released onJune 4th, 2023. For older changelogs please consult the release tag on GitHub Bug Fixes Ensure all data paths are resolved at runtime, not compile time Move data/ to priv/ since only priv/ is preserved in releases.","ref":"changelog.html#unicode-unihan-v0-3-0","title":"Changelog - Unicode Unihan v0.3.0","type":"extras"},{"doc":"This is the changelog for Unicode Unihan v0.2.0 released on May 31st, 2023. For older changelogs please consult the release tag on GitHub Enhancements Improves compilation time by orders of magnitude by switching to use :persistent_term for storing the Unihan database.","ref":"changelog.html#unicode-unihan-v0-2-0","title":"Changelog - Unicode Unihan v0.2.0","type":"extras"},{"doc":"This is the changelog for Unicode Unihan v0.1.0 released on May 28th, 2023. For older changelogs please consult the release tag on GitHub Enhancements Initial Release.","ref":"changelog.html#unicode-unihan-v0-1-0","title":"Changelog - Unicode Unihan v0.1.0","type":"extras"},{"doc":"The UniHan database provides detailed descriptions for each CJK ideograph. These descriptions ( fields ) are plain text, and can themselves be grouped into categories. Fields in Unihan, for historical reasons, have names that begins with k . Examples include kGradeLevel , kKangXi , and kStrange . The string in each field can contain a single entry, or a list of entries separated by a delimiter; each entry is encoded in a special format according to the needs of the field. For example, kKangXi describes where to find the ideograph in the 《康熙字典》Kangxi Dictionary, and a typical entry may be &quot;1187.061&quot;. The user is expected to consult the Unihan specifications to interpret this as page 1187, position 6, and virtual (the trailing 1 indicates that the ideograph is not actually in the dictionary). The Unicode.Unihan module simplifies access by parsing these into sensible structures. Each character is represented as a map, with atom keys (e.g., :kKangXi ) used to access fields. Where multiple entries exists inside a field, they are split into a list; each entry is parsed into a map. The example entry above would be structured to %{ page : 1187 , position : 6 , virtual : true } The contents of entries are cast into appropriate types (for example, integer for page ). This facilitates access using the filter/1 and reject/1 functions: you can now isolate all characters in KangXi Dictionary between pages 1100--1200, or all the virtual characters; since filter/1 and reject/1 accepts arbitrary functions, you can even combine fields and compose a query for &quot;virtual characters in KangXi that is also grade-level 3 or below&quot;. In the accompanying pages, we describe in some detail what the fields are and how entries were parsed. These are grouped thematically as follows: Dictionary Indices : kCheungBauerIndex, kCihaiT, kCowles, kDaeJaweon, kFennIndex, kGSR, kHanYu, kIRGDaeJaweon, kIRGDaiKanwaZiten, kIRGHanyuDaZidian, kIRGKangXi, kKangXi, kKarlgren, kLau, kMatthews, kMeyerWempe, kMorohashi, kNelson, kSBGY Dictionary-like data : kAlternateTotalStrokes, kCangjie, kCheungBauer, kFenn, kFourCornerCode, kFrequency, kGradeLevel, kHDZRadBreak, kHKGlyph, kPhonetic, kStrange, kUnihanCore2020 IRG sources : kCompatibilityVariant, kIICore, kIRG_GSource, kIRG_HSource, kIRG_JSource, kIRG_KPSource, kIRG_KSource, kIRG_MSource, kIRG_SSource, kIRG_TSource, kIRG_UKSource, kIRG_USource, kIRG_VSource, kRSUnicode, kTotalStrokes Numeric values : kAccountingNumeric, kOtherNumeric, kPrimaryNumeric Other mappings : kBigFive, kCCCII, kCNS1986, kCNS1992, kEACC, kGB0, kGB1, kGB3, kGB5, kGB7, kGB8, kHKSCS, kIBMJapan, kJa, kJinmeiyoKanji, kJis0, kJis1, kJIS0213, kJoyoKanji, kKoreanEducationHanja, kKoreanName, kKPS0, kKPS1, kKSC0, kKSC1, kMainlandTelegraph, kPseudoGB1, kTaiwanTelegraph, kTGH, kXerox Radical Stroke Counts : kRSAdobe_Japan1_6, kRSKangXi Readings : kCantonese, kDefinition, kHangul, kHanyuPinlu, kHanyuPinyin, kJapaneseKun, kJapaneseOn, kKorean, kMandarin, kTang, kTGHZ2013, kVietnamese, kXHC1983 Variants : kSemanticVariant, kSimplifiedVariant, kSpecializedSemanticVariant, kSpoofingVariant, kTraditionalVariant, kZVariant","ref":"fields.html","title":"Unihan Fields","type":"extras"},{"doc":"","ref":"dictionary_indices.html","title":"Dictionary Indices","type":"extras"},{"doc":"Description The position of the character in Cheung Kwan-hin and Robert S. Bauer, The Representation of Cantonese with Chinese Characters, Journal of Chinese Linguistics, Monograph Series Number 18, 2002. The format is a three-digit page number followed by a two-digit position number, separated by a period. Shape of return Notes","ref":"dictionary_indices.html#kcheungbauerindex","title":"Dictionary Indices - kCheungBauerIndex","type":"extras"},{"doc":"Description The position of this character in the Cihai (辭海) dictionary, single volume edition, published in Hong Kong by the Zhonghua Bookstore, 1983 (reprint of the 1947 edition), ISBN 962-231-005-2. The position is indicated by a decimal number. The digits to the left of the decimal are the page number. The first digit after the decimal is the row on the page, and the remaining two digits after the decimal are the position on the row. Shape of return Notes","ref":"dictionary_indices.html#kcihait","title":"Dictionary Indices - kCihaiT","type":"extras"},{"doc":"Description The index or indices of this character in Roy T. Cowles, A Pocket Dictionary of Cantonese, Hong Kong: University Press, 1999. The Cowles indices are numerical, usually integers but occasionally fractional where a character was added after the original indices were determined. Cowles is missing indices 1222 and 4949, and four characters in Cowles are part of Unicode’s “Hangzhou” numeral set: 2964 (U+3025), 3197 (U+3028), 3574 (U+3023), and 4720 (U+3027). Shape of return Notes","ref":"dictionary_indices.html#kcowles","title":"Dictionary Indices - kCowles","type":"extras"},{"doc":"Description The position of this character in the Dae Jaweon (Korean) dictionary used in the four-dictionary sorting algorithm. The position is in the form “page.position” with the final digit in the position being “0” for characters actually in the dictionary and “1” for characters not found in the dictionary and assigned a “virtual” position in the dictionary. Thus, “1187.060” indicates the sixth character on page 1187. A character not in this dictionary but assigned a position between the 6th and 7th characters on page 1187 for sorting purposes would have the code “1187.061” The edition used is the first edition, published in Seoul by Samseong Publishing Co., Ltd., 1988. Shape of return Notes","ref":"dictionary_indices.html#kdaejaweon","title":"Dictionary Indices - kDaeJaweon","type":"extras"},{"doc":"Description The position of this character in The Five Thousand Dictionary by Courtenay H. Fenn, Cambridge, Mass.: Harvard University Press, 1979. The position is indicated by a three-digit page number followed by a period and a two-digit position on the page. Shape of return Notes","ref":"dictionary_indices.html#kfennindex","title":"Dictionary Indices - kFennIndex","type":"extras"},{"doc":"Description The position of this character in Bernhard Karlgren’s Grammata Serica Recensa (1957). This dataset contains a total of 7,405 records. References are given in the form DDDDa('), where “DDDD” is a set number in the range [0001..1260] zero-padded to 4-digits, “a” is a letter in the range [a..z] (excluding “w”), optionally followed by apostrophe ('). The data from which this mapping table is extracted contains a total of 10,023 references. References to inscriptional forms have been omitted. This entry is abridged. See Annex #38 for a more complete description. Shape of return Notes","ref":"dictionary_indices.html#kgsr","title":"Dictionary Indices - kGSR","type":"extras"},{"doc":"Description The position of this character in the Hànyǔ Dà Zìdiǎn (HDZ) Chinese character dictionary (bibliographic information below). The character references are given in the form “ABCDE.XYZ”, in which: “A” is the volume number [1..8]; “BCDE” is the zero-padded page number [0001..4809]; “XY” is the zero-padded number of the character on the page [01..32]; “Z” is “0” for a character actually in the dictionary, and greater than 0 for a character assigned a “virtual” position in the dictionary. For example, 53024.060 indicates an actual HDZ character, the 6th character on Page 3,024 of Volume 5 (i.e. 籉 [U+7C49]). Note that the Volume 8 “BCDE” references are in the range [0008..0044] inclusive, referring to the pagination of the “Appendix of Addendum” at the end of that volume (beginning after p. 5746). The first character assigned a given virtual position has an index ending in 1; the second assigned the same virtual position has an index ending in 2; and so on. This entry is abridged. See Annex #38 for a more complete description. Shape of return Notes","ref":"dictionary_indices.html#khanyu","title":"Dictionary Indices - kHanYu","type":"extras"},{"doc":"Description The position of this character in the Dae Jaweon (Korean) dictionary used in the four-dictionary sorting algorithm. The position is in the form “page.position” with the final digit in the position being “0” for characters actually in the dictionary and “1” for characters not found in the dictionary and assigned a “virtual” position in the dictionary. Thus, “1187.060” indicates the sixth character on page 1187. A character not in this dictionary but assigned a position between the 6th and 7th characters on page 1187 for sorting purposes would have the code “1187.061” This field represents the official position of the character within the Dae Jaweon dictionary as used by the IRG in the four-dictionary sorting algorithm. The edition used is the first edition, published in Seoul by Samseong Publishing Co., Ltd., 1988. Shape of return Notes","ref":"dictionary_indices.html#kirgdaejaweon","title":"Dictionary Indices - kIRGDaeJaweon","type":"extras"},{"doc":"Description The index of this character in the Dai Kanwa Ziten, aka Morohashi dictionary (Japanese) used in the four-dictionary sorting algorithm. This field represents the official position of the character within the Dai Kanwa Ziten as used by the IRG in the four-dictionary sorting algorithm. The edition used is the revised edition, published in Tokyo by Taishuukan Shoten, 1986. Shape of return Notes","ref":"dictionary_indices.html#kirgdaikanwaziten","title":"Dictionary Indices - kIRGDaiKanwaZiten","type":"extras"},{"doc":"Description The position of this character in the Hànyǔ Dà Zìdiǎn (PRC) dictionary used in the four-dictionary sorting algorithm. The position is in the form “volume page.position” with the final digit in the position being “0” for characters actually in the dictionary and “1” for characters not found in the dictionary and assigned a “virtual” position in the dictionary. Thus, “32264.080” indicates the eighth character on page 2264 in volume 3. A character not in this dictionary but assigned a position between the 8th and 9th characters on this page for sorting purposes would have the code “32264.081” This field represents the official position of the character within the Hànyǔ Dà Zìdiǎn dictionary as used by the IRG in the four-dictionary sorting algorithm. The edition of the Hanyu Da Zidian used is the first edition, published in Chengdu by Sichuan Cishu Publishing, 1986. Shape of return Notes","ref":"dictionary_indices.html#kirghanyudazidian","title":"Dictionary Indices - kIRGHanyuDaZidian","type":"extras"},{"doc":"Description The official IRG position of this character in the 《康熙字典》 Kangxi Dictionary used in the four-dictionary sorting algorithm. The position is in the form “page.position” with the final digit in the position being “0” for characters actually in the dictionary and “1” for characters not found in the dictionary but assigned a “virtual” position in the dictionary. Thus, “1187.060” indicates the sixth character on page 1187. A character not in this dictionary but assigned a position between the 6th and 7th characters on page 1187 for sorting purposes would have the code “1187.061”. The edition of the Kangxi Dictionary used is the 7th edition published by Zhonghua Bookstore in Beijing, 1989. The values in the kIRGKangXi field are a strict subset of those in the kKangXi field. Shape of return Notes","ref":"dictionary_indices.html#kirgkangxi","title":"Dictionary Indices - kIRGKangXi","type":"extras"},{"doc":"Description The position of this character in the《康熙字典》Kangxi Dictionary used in the four-dictionary sorting algorithm. The position is in the form “page.position” with the final digit in the position being “0” for characters actually in the dictionary and “1” for characters not found in the dictionary but assigned a “virtual” position in the dictionary. Thus, “1187.060” indicates the sixth character on page 1187. A character not in this dictionary but assigned a position between the 6th and 7th characters on page 1187 for sorting purposes would have the code “1187.061”. The edition of the Kangxi Dictionary used is the 7th edition published by Zhonghua Bookstore in Beijing, 1989. The values in the kKangXi field are a strict superset of those in the kIRGKangXi field. Shape of return Notes","ref":"dictionary_indices.html#kkangxi","title":"Dictionary Indices - kKangXi","type":"extras"},{"doc":"Description The index of this character in Analytic Dictionary of Chinese and Sino-Japanese by Bernhard Karlgren, New York: Dover Publications, Inc., 1974. If the index is followed by an asterisk (*), then the index is an interpolated one, indicating where the character would be found if it were to have been included in the dictionary. Note that while the index itself is usually an integer, there are some cases where it is an integer followed by an “A”. Shape of return Notes","ref":"dictionary_indices.html#kkarlgren","title":"Dictionary Indices - kKarlgren","type":"extras"},{"doc":"Description The index of this character in A Practical Cantonese-English Dictionary by Sidney Lau, Hong Kong: The Government Printer, 1977. The index consists of an integer. Missing indices indicate characters to be found in [UAX45]. Shape of return Notes","ref":"dictionary_indices.html#klau","title":"Dictionary Indices - kLau","type":"extras"},{"doc":"Description The index of this character in Chinese-English Dictionary by Robert H. Mathews, Cambridge: Harvard University Press, 1975. Note that the field name is kMatthews instead of kMathews to maintain compatibility with earlier versions of this file, where it was inadvertently misspelled. Shape of return Notes","ref":"dictionary_indices.html#kmatthews","title":"Dictionary Indices - kMatthews","type":"extras"},{"doc":"Description The index of this character in the Student’s Cantonese-English Dictionary by Bernard F. Meyer and Theodore F. Wempe (3rd edition, 1947). The index is an integer, optionally followed by a lowercase Latin letter if the listing is in a subsidiary entry and not a main one. In some cases, where the character is found in the radical-stroke index, but not in the main body of the dictionary, the integer is followed by an asterisk: for example, U+50E5 僥, which is listed as 736* as well as 1185a. Shape of return Notes","ref":"dictionary_indices.html#kmeyerwempe","title":"Dictionary Indices - kMeyerWempe","type":"extras"},{"doc":"Description The index of this character in the Dai Kanwa Ziten, aka Morohashi dictionary (Japanese) used in the four-dictionary sorting algorithm. The edition used is the revised edition, published in Tokyo by Taishūkan Shoten, 1986. Shape of return Notes","ref":"dictionary_indices.html#kmorohashi","title":"Dictionary Indices - kMorohashi","type":"extras"},{"doc":"Description The index of this character in The Modern Reader’s Japanese-English Character Dictionary by Andrew Nathaniel Nelson, Rutland, Vermont: Charles E. Tuttle Company, 1974. Shape of return Notes","ref":"dictionary_indices.html#knelson","title":"Dictionary Indices - kNelson","type":"extras"},{"doc":"Description The position of this character in the Song Ben Guang Yun (SBGY) Medieval Chinese character dictionary (bibliographic and general information below). The 25334 character references are given in the form “ABC.XY”, in which: “ABC” is the zero-padded page number [004..546]; “XY” is the zero-padded number of the character on the page [01..73]. For example, 364.38 indicates the 38th character on Page 364 (i.e. 澍). Where a given Unicode Scalar Value (USV) has more than one reference, these are space-delimited. This is an abridged entry. For details see Annex #38 . Shape of return Notes","ref":"dictionary_indices.html#ksbgy","title":"Dictionary Indices - kSBGY","type":"extras"},{"doc":"","ref":"dictionary_like_data.html","title":"Dictionary-like data","type":"extras"},{"doc":"Description The total number of strokes in the character (including the radical). Each value consists either of a decimal value followed by an IRG source specifier as defined in Section 3.10, or of the special value “-”. The IRG source specifier indicates the IRG sources for which a particular value is preferred. The source identifiers “G” and “T” are not used in this field, as these IRG sources are fully covered by the kTotalStrokes field. The stroke count value is the one for the glyph as shown in the code charts. Multiple stroke counts are listed in increasing numeric order. Stroke counts may not be repeated. This is an abridged entry. For examples and details, see its entry in Annex #38. Shape of return Notes","ref":"dictionary_like_data.html#kalternatetotalstrokes","title":"Dictionary-like data - kAlternateTotalStrokes","type":"extras"},{"doc":"Description The cangjie input code for the character. This incorporates data from the file cangjie-table.b5 by Christian Wittern. Shape of return Notes","ref":"dictionary_like_data.html#kcangjie","title":"Dictionary-like data - kCangjie","type":"extras"},{"doc":"Description Data regarding the character in Cheung Kwan-hin and Robert S. Bauer, The Representation of Cantonese with Chinese Characters, Journal of Chinese Linguistics, Monograph Series Number 18, 2002. Each data value consists of three pieces, separated by semicolons: (1) the character’s radical-stroke index as a three-digit radical, slash, two-digit stroke count; (2) the character’s cangjie input code (if any); and (3) a comma-separated list of Cantonese readings using the jyutping romanization in alphabetical order. Shape of return Notes","ref":"dictionary_like_data.html#kcheungbauer","title":"Dictionary-like data - kCheungBauer","type":"extras"},{"doc":"Description Data on the character from The Five Thousand Dictionary by Courtenay H. Fenn, Cambridge, Mass.: Harvard University Press, 1979. The data here consists of a decimal number followed by a letter A through K, the letter P, or an asterisk. The decimal number gives the Soothill number for the character’s phonetic, and the letter is a rough frequency indication, with A indicating the 500 most common ideographs, B the next five hundred, and so on. P is used by Fenn to indicate a rare character included in the dictionary only because it is the phonetic element in other characters. An asterisk is used instead of a letter in the final position to indicate a character which belongs to one of Soothill’s phonetic groups but is not found in Fenn’s dictionary. Characters which have a frequency letter but no Soothill phonetic group are assigned group 0. Shape of return Notes","ref":"dictionary_like_data.html#kfenn","title":"Dictionary-like data - kFenn","type":"extras"},{"doc":"Description The four-corner code(s) for the character. This data is derived from data provided in the public domain by Hartmut Bohn, Urs App, and Christian Wittern. The four-corner system assigns each character a four-digit code from 0 through 9. The digit is derived from the “shape” of the four corners of the character (upper-left, upper-right, lower-left, lower-right). An optional fifth digit can be used to further distinguish characters; the fifth digit is derived from the shape in the character’s center or region immediately to the left of the fourth corner. The four-corner system is now used only rarely. Full descriptions are available online, for example, at http://en.wikipedia.org/wiki/Four_corner_input . Values in this field consist of four decimal digits, optionally followed by a period and fifth digit for a five-digit form. Shape of return Notes","ref":"dictionary_like_data.html#kfourcornercode","title":"Dictionary-like data - kFourCornerCode","type":"extras"},{"doc":"Description A rough frequency measurement for the character based on analysis of traditional Chinese USENET postings; characters with a kFrequency of 1 are the most common, those with a kFrequency of 2 are less common, and so on, through a kFrequency of 5. Shape of return Notes","ref":"dictionary_like_data.html#kfrequency","title":"Dictionary-like data - kFrequency","type":"extras"},{"doc":"Description The primary grade in the Hong Kong school system by which a student is expected to know the character; this data is derived from 朗文初級中文詞典, Hong Kong: Longman, 2001. Shape of return Notes","ref":"dictionary_like_data.html#kgradelevel","title":"Dictionary-like data - kGradeLevel","type":"extras"},{"doc":"Description Indicates that 《漢語大字典》 Hanyu Da Zidian has a radical break beginning at this character’s position. The field consists of the radical (with its Unicode code point), a colon, and then the Hanyu Da Zidian position as in the kHanyu field. Shape of return Notes","ref":"dictionary_like_data.html#khdzradbreak","title":"Dictionary-like data - kHDZRadBreak","type":"extras"},{"doc":"Description The index of the character in 常用字字形表 (二零零零年修訂本),香港: 香港教育學院, 2000, ISBN 962-949-040-4. This publication gives the “proper” shapes for 4759 characters as used in the Hong Kong school system. The index is an integer, zero-padded to four digits. Shape of return Notes","ref":"dictionary_like_data.html#khkglyph","title":"Dictionary-like data - kHKGlyph","type":"extras"},{"doc":"Description The phonetic class for the character, as adopted from Ten Thousand Characters: An Analytic Dictionary, by G. Hugh Casey, S.J. Hong Kong: Kelly and Walsh, 1980. Characters in the same phonetic class have a common phonetic element, such as 耕 (U+8015) and 阱 (U+9631), both assigned to the phonetic class 103. Most classes have a prototype character, which serves as the common phonetic element for the remaining members of the class. For example, 乍 (U+4E4D) is the prototype for characters of class 10. Some classes are associated with one to four subsidiary classes, indicated by the letters A through D. Some characters are assigned multiple classes. This can happen, for example, when a character belongs to one class but is also the prototype for a different class. For example, 國 (U+570B) is the prototype for class 748, but is also a member of class 1416, which has 或 (U+6216) as its prototype. Its kPhonetic value is therefore &quot;748 1416.&quot; Multiple values are always in ascending numerical order. An asterisk is appended when a character has the given phonetic class but is not explicitly included in the character list for that class. For example, 蝓 (U+8753) belongs to the class 1611 but is not explicitly listed in that class. Its kPhonetic value is therefore &quot;1611*&quot;. Casey includes a radical-stroke index mapping characters to their phonetic class. In some cases, this mapping is in error; when this happens, a lowercase &quot;x&quot; is appended to the index. For example, 萑 (U+8411) is assigned to the classes 216 and 285, but the assignment to class 216 is clearly in error. Its kPhonetic value is therefore &quot;216x 285&quot;. Shape of return Notes","ref":"dictionary_like_data.html#kphonetic","title":"Dictionary-like data - kPhonetic","type":"extras"},{"doc":"Description This property identifies CJK Unified Ideographs that are considered &quot;strange&quot; in one or more ways per the following 12 categories: Category A = [A]symmetric (exhibits a structure that is asymmetric) Category B = [B]opomofo (visually resembles a bopomofo character) Category C = [C]ursive (is cursive or includes one or more cursive components that do not adhere to Han ideograph stroke conventions) Category F = [F]ully-reflective (is fully-reflective or includes components that are fully-reflective, meaning that the mirrored and unmirrored components are arranged side-by-side or stacked top-and-bottom) Category H = [H]angul Component (includes a hangul component) Category I = [I]ncomplete (appears to be an incomplete version of an existing or possible ideograph, meaning that one or more components appear to be incomplete, without regard to semantics) Category K = [K]atakana Component (includes one or more components that visually resemble a katakana syllable) Category M = [M]irrored (is either mirrored or includes one or more components that are mirrored) Category O = [O]dd Component (includes one or more components that are symbol-like or are otherwise considered odd) Category R = [R]otated (is either rotated or includes one or more components that are rotated) Category S = [S]troke-heavy (has 40 or more strokes) Category U = [U]nusual Arrangement/Structure (has an unusual structure or component arrangement) This property is fully documented in UTN43 , Unihan Database Property “kStrange”. Shape of return Notes","ref":"dictionary_like_data.html#kstrange","title":"Dictionary-like data - kStrange","type":"extras"},{"doc":"Description Used for characters which are in the UnihanCore2020 set, the minimal set of required ideographs for East Asia. A character is in the UnihanCore2020 set if and only if it has a value for the kUnihanCore2020 property. Shape of return Notes","ref":"dictionary_like_data.html#kunihancore2020","title":"Dictionary-like data - kUnihanCore2020","type":"extras"},{"doc":"","ref":"irg_sources.html","title":"IRG sources","type":"extras"},{"doc":"Description The canonical Decomposition_Mapping value for the ideograph, derived from UnicodeData.txt. This field is derived by taking the non-null Decomposition_Mapping values from Field 5 of UnicodeData.txt, for characters contained within the CJK Compatibility Ideographs block and the CJK Compatibility Ideographs Supplement block. Shape of return Notes","ref":"irg_sources.html#kcompatibilityvariant","title":"IRG sources - kCompatibilityVariant","type":"extras"},{"doc":"Description Used for characters which are in IICore, the IRG-produced minimal set of required ideographs for East Asian use. A character is in IICore if and only if it has a value for the kIICore field. Each value consists of a letter (A, B, or C), indicating priority value, followed by an IRG source specifier as defined in Section 3.10 above. Shape of return Notes","ref":"irg_sources.html#kiicore","title":"IRG sources - kIICore","type":"extras"},{"doc":"Description The IRG “G” source mapping for this character in hexadecimal or decimal. The IRG G source consists of data from the following national standards, publications, and lists from the People’s Republic of China and Singapore. The versions of the standards used are those provided by the PRC to the IRG and may not always reflect published versions of the standards generally available. This is an abridged entry. For what the G source standards are referring to, see the kIRG_GSource entry in Annex #38. Shape of return Notes","ref":"irg_sources.html#kirg_gsource","title":"IRG sources - kIRG_GSource","type":"extras"},{"doc":"Description The IRG “H” source mapping for this character in hexadecimal. The IRG “H” source consists of data from the following sources: H Hong Kong Supplementary Character Set – 2008 HB0 Big-5: Computer Chinese Glyph and Character Code Mapping Table, Technical Report C-26, 電腦用中文字型與字碼對照表, 技術通報C-26, 1984, Symbols HB1 Big-5, Level 1 HB2 Big-5, Level 2 HD Hong Kong Supplementary Character Set – 2016 HU The source reference for this character has been moved; the value is its code point. Shape of return Notes","ref":"irg_sources.html#kirg_hsource","title":"IRG sources - kIRG_HSource","type":"extras"},{"doc":"Description The IRG “J” source mapping for this character in hexadecimal or decimal. The IRG “J” source consists of data from the following national standards and lists from Japan. This is an abridged entry. See the kIRG_JSource entry in Annex #38 for detailed list of what national standards are referred to by the acronyms. Shape of return Notes","ref":"irg_sources.html#kirg_jsource","title":"IRG sources - kIRG_JSource","type":"extras"},{"doc":"Description The IRG “KP” source mapping for this character in hexadecimal. The IRG “KP” source consists of data from the following national standards and lists from the Democratic People’s Republic of Korea (North Korea). KP0 KPS 9566-97 KP1 KPS 10721-2000 KPU The source reference for this character has been moved; the value is its code point. It is currently not possible to communicate with standards bodies within the DPRK. There may, therefore, be erroneous data in the values for this field. Shape of return Notes","ref":"irg_sources.html#kirg_kpsource","title":"IRG sources - kIRG_KPSource","type":"extras"},{"doc":"Description The IRG “K” source mapping for this character in hexadecimal or decimal. The IRG “K” source consists of data from the following national standards and lists from the Republic of Korea (South Korea). This is an abridged entry. See the kIRG_KSource entry in Annex #38 for detailed list of what national standards are referred to by the acronyms. Shape of return Notes","ref":"irg_sources.html#kirg_ksource","title":"IRG sources - kIRG_KSource","type":"extras"},{"doc":"Description The IRG “M” source mapping for this character in decimal. The IRG “M” source corresponds to MSCS (Macao Supplementary Character Set). MA HKSCS-2008 code point in hexadecimal MB Big Five code point in hexadecimal MC MSCS reference MD MSCS horizontal extensions Shape of return Notes","ref":"irg_sources.html#kirg_msource","title":"IRG sources - kIRG_MSource","type":"extras"},{"doc":"Description The IRG “S” source mapping for this character that corresponds to Taishō Shinshū Daizōkyō (大正新脩大藏經), 1924–1934, which is accessible in the SAT Daizōkyō Text Database. The source references consist of “SAT” followed by a hyphen and five decimal digits, zero padded. Shape of return Notes","ref":"irg_sources.html#kirg_ssource","title":"IRG sources - kIRG_SSource","type":"extras"},{"doc":"Description The IRG “T” source mapping for this character in hexadecimal. The IRG “T” source consists of data from the following standards and lists. “TCA” stands for “Taipei Computer Association,” and “CNS” stands for “Chinese National Standard.” This is an abridged entry. See the kIRG_TSource entry in Annex #38 for detailed list of what national standards are referred to by the acronyms. Shape of return Notes","ref":"irg_sources.html#kirg_tsource","title":"IRG sources - kIRG_TSource","type":"extras"},{"doc":"Description The IRG “UK” source mapping for this character in decimal. The source references consist of “UK” followed by a hyphen and five decimal digits, zero padded. The IRG “UK” source currently consists of data from the documents IRG N2107R2 and IRG N2232R that are available in the UK-source Ideographs repository . Shape of return Notes","ref":"irg_sources.html#kirg_uksource","title":"IRG sources - kIRG_UKSource","type":"extras"},{"doc":"Description The IRG “U” source mapping for this character in decimal. U-source references are a reference into the U-source ideograph database; see [UAX45]. They consist of “UTC” followed by a hyphen and a five-digit, zero-padded index into the database. Shape of return Notes","ref":"irg_sources.html#kirg_usource","title":"IRG sources - kIRG_USource","type":"extras"},{"doc":"Description The IRG “V” source mapping for this character in hexadecimal. The IRG “V” source consists of data from the following national standards and lists from Vietnam. V0 TCVN 5773:1993 V1 TCVN 6056:1995 V2 VHN 01:1998 V3 VHN 02: 1998 V4 Kho Chữ Hán Nôm Mã Hoá (Hán Nôm Coded Character Repertoire), Hà Nội, 2007 VN Vietnamese horizontal extensions; the value is its code point Shape of return Notes","ref":"irg_sources.html#kirg_vsource","title":"IRG sources - kIRG_VSource","type":"extras"},{"doc":"Description The standard radical-stroke count for this character in the form “radical.additional strokes”. The radical is indicated by a number in the range (1..214) inclusive. An apostrophe (') after the radical indicates a simplified version of the given radical. The “additional strokes” value is the residual stroke-count, the count of all strokes remaining after eliminating all strokes associated with the radical. This field is also used for additional radical-stroke indices where either a character may be reasonably classified under more than one radical, or alternate stroke count algorithms may provide different stroke counts. The residual stroke count may be negative. This is because some characters (for example, U+225A9, U+29C0A) are constructed by removing strokes from a standard radical. Shape of return Notes","ref":"irg_sources.html#krsunicode","title":"IRG sources - kRSUnicode","type":"extras"},{"doc":"Description The total number of strokes in the character (including the radical). When there are two values, then the first is preferred for zh-Hans (CN) and the second is preferred for zh-Hant (TW). When there is only one value, it is appropriate for both. The preferred value is the one most commonly associated with the character in modern text using customary fonts. This field is targeted specifically for use by CLDR collation and transliteration. As such, it is subject to considerations that help keep pīnyīn-based Han collation (and its tailorings) and transliteration reasonably stable. Shape of return Notes","ref":"irg_sources.html#ktotalstrokes","title":"IRG sources - kTotalStrokes","type":"extras"},{"doc":"","ref":"numeric_values.html","title":"Numeric values","type":"extras"},{"doc":"Description The value of the character when used as an accounting numeral to prevent fraud. A numeral such as 十 (ten) is easily transformed into 千 (thousand) by adding a single stroke, so monetary documents often use an accounting form of the numeral, such as 拾 (ten), instead of the more common—and simpler—form. Characters with this property will have a single, well-defined value, which a native reader can reasonably be expected to understand. The three numeric-value fields should have no overlap; that is, characters with a kAccountingNumeric value should not have a kOtherNumeric or kPrimaryNumeric value as well. Shape of return Notes","ref":"numeric_values.html#kaccountingnumeric","title":"Numeric values - kAccountingNumeric","type":"extras"},{"doc":"Description One or more values of the character when used as a numeral. Characters with this property are rarely used for writing numbers, or have non-standard or multiple values depending on the region. For example, 㠪 is a rare character whose meaning, “five,” would not be recognized by most native readers. An English-language equivalent is “gross,” whose numeric value, “one hundred forty-four,” is not universally understood by native readers. The three numeric-value fields should have no overlap; that is, characters with a kOtherNumeric value should not have a kAccountingNumeric or kPrimaryNumeric value as well. Shape of return Notes","ref":"numeric_values.html#kothernumeric","title":"Numeric values - kOtherNumeric","type":"extras"},{"doc":"Description The value of the character when used as a numeral. Characters which have this property have numeric values that are common, and always convey the same numeric value. For example, 千 always means “thousand.” A native reader is expected to understand the numeric value for these characters. The three numeric-value fields should have no overlap; that is, characters with a kPrimaryNumeric value should not have a kAccountingNumeric or kOtherNumeric value as well. Shape of return Notes","ref":"numeric_values.html#kprimarynumeric","title":"Numeric values - kPrimaryNumeric","type":"extras"},{"doc":"","ref":"other_mappings.html","title":"Other mappings","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kbigfive","title":"Other mappings - kBigFive","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kcccii","title":"Other mappings - kCCCII","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kcns1986","title":"Other mappings - kCNS1986","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kcns1992","title":"Other mappings - kCNS1992","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#keacc","title":"Other mappings - kEACC","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kgb0","title":"Other mappings - kGB0","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kgb1","title":"Other mappings - kGB1","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kgb3","title":"Other mappings - kGB3","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kgb5","title":"Other mappings - kGB5","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kgb7","title":"Other mappings - kGB7","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kgb8","title":"Other mappings - kGB8","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#khkscs","title":"Other mappings - kHKSCS","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kibmjapan","title":"Other mappings - kIBMJapan","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kja","title":"Other mappings - kJa","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kjinmeiyokanji","title":"Other mappings - kJinmeiyoKanji","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kjis0","title":"Other mappings - kJis0","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kjis1","title":"Other mappings - kJis1","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kjis0213","title":"Other mappings - kJIS0213","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kjoyokanji","title":"Other mappings - kJoyoKanji","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kkoreaneducationhanja","title":"Other mappings - kKoreanEducationHanja","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kkoreanname","title":"Other mappings - kKoreanName","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kkps0","title":"Other mappings - kKPS0","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kkps1","title":"Other mappings - kKPS1","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kksc0","title":"Other mappings - kKSC0","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kksc1","title":"Other mappings - kKSC1","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kmainlandtelegraph","title":"Other mappings - kMainlandTelegraph","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kpseudogb1","title":"Other mappings - kPseudoGB1","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#ktaiwantelegraph","title":"Other mappings - kTaiwanTelegraph","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#ktgh","title":"Other mappings - kTGH","type":"extras"},{"doc":"Description Shape of return Notes","ref":"other_mappings.html#kxerox","title":"Other mappings - kXerox","type":"extras"},{"doc":"","ref":"radical_stroke_counts.html","title":"Radical stroke-counts","type":"extras"},{"doc":"Description Information on the glyphs in Adobe-Japan1-6 as contributed by Adobe. The value consists of a number of space-separated entries. Each entry consists of three pieces of information separated by a plus sign: C or V. “C” indicates that the Unicode code point maps directly to the Adobe-Japan1-6 CID that appears after it, and “V” indicates that it is considered a variant form, and thus not directly encoded. The Adobe-Japan1-6 CID. Radical-stroke data for the indicated Adobe-Japan1-6 CID. The radical-stroke data consists of three pieces separated by periods: the Kangxi radical (1-214), the number of strokes in the form the radical takes in the glyph, and the number of strokes in the residue. The standard Unicode radical-stroke form can be obtained by omitting the second value, and the total strokes in the glyph from adding the second and third values. Shape of return Notes","ref":"radical_stroke_counts.html#krsadobe_japan1_6","title":"Radical stroke-counts - kRSAdobe_Japan1_6","type":"extras"},{"doc":"Description The Kangxi radical-stroke count for this character consistent with the value of the kKangXi field in the form “radical.additional strokes”. Shape of return Notes","ref":"radical_stroke_counts.html#krskangxi","title":"Radical stroke-counts - kRSKangXi","type":"extras"},{"doc":"","ref":"readings.html","title":"Readings","type":"extras"},{"doc":"Description The most customary jyutping (Cantonese) reading for this character. This field is targeted specifically for use by CLDR collation and transliteration. As such, it is subject to considerations that help keep jyutping-based Han collation (and its tailorings) and transliteration reasonably stable. The values may not in all cases track the preferred reading in some dictionaries. This is an abridged entry. For sources, see the kCantonese entry in Annex #38. Shape of return Notes","ref":"readings.html#kcantonese","title":"Readings - kCantonese","type":"extras"},{"doc":"Description An English definition for this character. Definitions are for modern written Chinese and are usually (but not always) the same as the definition in other Chinese dialects or non-Chinese languages. In some cases, synonyms are indicated. Fuller variant information can be found using the various variant fields. Definitions specific to non-Chinese languages or Chinese dialects other than modern Mandarin are marked, for example, (Cant.) or (J). Major definitions are separated by semicolons, and minor definitions by commas. Any valid Unicode character (except for tab, double-quote, and any line break character) may be used within the definition field. Shape of return Notes","ref":"readings.html#kdefinition","title":"Readings - kDefinition","type":"extras"},{"doc":"Description The modern Korean pronunciation(s) for this character in Hangul, with its source(s) following a colon. A value of 0 corresponds to KS X 1001, a value of 1 corresponds to KS X 1002, a value of E corresponds to 한문 교육용 기초 한자 (漢文敎育用基礎漢字), and a value of N corresponds to 인명용 한자 (人名用漢字). A value of X indicates that a K-source was formerly at that code point but was later removed. Shape of return Notes","ref":"readings.html#khangul","title":"Readings - kHangul","type":"extras"},{"doc":"Description The Pronunciations and Frequencies of this character, based in part on those appearing in 《現代漢語頻率詞典》 &lt;Xiandai Hanyu Pinlu Cidian&gt; (XDHYPLCD) [Modern Standard Beijing Chinese Frequency Dictionary] (complete bibliographic information below). This dataset contains a total of 3799 records. (The original data provided to Unihan 2003/02/04 contained a total of 3800 records, including 〇 [U+3007] líng ‘IDEOGRAPHIC NUMBER ZERO’, not included in Unihan since it is not a CJK UNIFIED IDEOGRAPH.) Each entry is comprised of two pieces of data. The Hanyu Pinyin (HYPY) pronunciation(s) of the character. Immediately following the pronunciation, a numeric string appears in parentheses: for example, in “ā(392)” the numeric string “392” indicates the sum total of the frequencies of the pronunciations of the character as given in HYPLCD. Where more than one pronunciation exists, these are sorted by descending frequency, and the list elements are “space” delimited. This is an abridged description. For release information, see the kHanyuPinlu field in Annex #38. Shape of return Notes","ref":"readings.html#khanyupinlu","title":"Readings - kHanyuPinlu","type":"extras"},{"doc":"Description The 漢語拼音 Hànyǔ Pīnyīn reading(s) appearing in the edition of 《漢語大字典》 Hànyǔ Dà Zìdiǎn (HDZ) specified in the “kHanYu” property description (q.v.). Each location has the form “ABCDE.XYZ” (as in “kHanYu”); multiple locations for a given pīnyīn reading are separated by commas. The list of locations is followed by a colon, followed by a comma-separated list of one or more pīnyīn readings. Where multiple pīnyīn readings are associated with a given mapping, these are ordered as in HDZ (for the most part reflecting relative commonality). The following are representative records. | U+34CE | 㓎 | 10297.260: qīn,qìn,qǐn | | U+34D8 | 㓘 | 10278.080,10278.090: sù | | U+5364 | 卤 | 10093.130: xī,lǔ 74609.020: lǔ,xī | | U+5EFE | 廾 | 10513.110,10514.010,10514.020: gǒng | For example, the “kHanyuPinyin” value for 卤 U+5364 is “10093.130: xī,lǔ 74609.020: lǔ,xī”. This means that 卤 U+5364 is found in “kHanYu” at entries 10093.130 and 74609.020. The former entry has the two pīnyīn readings xī and lǔ (in that order), whereas the latter entry has the readings lǔ and xī (reversing the order). This data was originally input by 井作恆 Jǐng Zuòhéng, proofed by 聃媽歌 Dān Māgē (Magda Danish, using software donated by 文林 Wénlín Institute, Inc. and tables prepared by 曲理查 Qū Lǐchá), and proofed again and prepared for the Unicode Consortium by 曲理查 Qū Lǐchá (2008-01-14). -- Release Notes -- This data set includes readings for 34,130 distinct HDZ Hànzì, 34,302 HDZ references, and 1,457 distinct pīnyīn syllables. Shape of return Notes","ref":"readings.html#khanyupinyin","title":"Readings - kHanyuPinyin","type":"extras"},{"doc":"Description The Japanese pronunciation(s) of this character in the Hepburn romanization. Shape of return Notes","ref":"readings.html#kjapanesekun","title":"Readings - kJapaneseKun","type":"extras"},{"doc":"Description The Sino-Japanese pronunciation(s) of this character. Shape of return Notes","ref":"readings.html#kjapaneseon","title":"Readings - kJapaneseOn","type":"extras"},{"doc":"Description The Korean pronunciation(s) of this character, using the Yale romanization system. (See http://en.wikipedia.org/wiki/Korean_romanization for a discussion of the various Korean romanization systems.) Use of the kKorean field is not recommended. The kHangul field, which is aligned to the KS X 1001 and KS X 1002 standards, 한문 교육용 기초 한자 (漢文敎育用基礎漢字), and 인명용 한자 (人名用漢字), is recommended to be used instead. Shape of return Notes","ref":"readings.html#kkorean","title":"Readings - kKorean","type":"extras"},{"doc":"Description The most customary pīnyīn reading for this character. When there are two values, then the first is preferred for zh-Hans (CN) and the second is preferred for zh-Hant (TW). When there is only one value, it is appropriate for both. This field is targeted specifically for use by CLDR collation and transliteration. As such, it is subject to considerations that help keep pīnyīn-based Han collation (and its tailorings) and transliteration reasonably stable. The values may not in all cases track the preferred use in some dictionaries. Shape of return Notes","ref":"readings.html#kmandarin","title":"Readings - kMandarin","type":"extras"},{"doc":"Description The Tang dynasty pronunciation(s) of this character, derived from or consistent with T’ang Poetic Vocabulary by Hugh M. Stimson, Far Eastern Publications, Yale University 1976. An asterisk indicates that the word or morpheme represented in toto or in part by the given character with the given reading occurs more than four times in the seven hundred poems covered. Shape of return Notes","ref":"readings.html#ktang","title":"Readings - kTang","type":"extras"},{"doc":"Description One or more Hànyǔ Pīnyīn readings as given in Tōngyòng Guīfàn Hànzì Zìdiǎn (full bibliographic information below). Each pīnyīn reading is preceded by the character’s location(s) in the dictionary, separated from the reading by a colon. Multiple locations for a given reading are separated by commas. Multiple “location: reading” values are separated by a space. Each location reference is of the form /[0-9]{3}.[0-9]{3}/. The number preceding the period is the page number, zero-padded to three digits. The first two digits of the number following the period are the entry’s position on the page, zero-padded. The third digit is 0 for a main entry and greater than 0 for a parenthesized or bracketed variant of the main entry. This is an abridged description. For bibliographic information, see the field entry in Annex #38. Shape of return Notes","ref":"readings.html#ktghz2013","title":"Readings - kTGHZ2013","type":"extras"},{"doc":"Description The character’s pronunciation(s) in Quốc ngữ. Shape of return Notes","ref":"readings.html#kvietnamese","title":"Readings - kVietnamese","type":"extras"},{"doc":"Description One or more Hànyǔ Pīnyīn readings as given in the Xiàndài Hànyǔ Cídiǎn (full bibliographic information below). Each pīnyīn reading is preceded by the character’s location(s) in the dictionary, separated from the reading by a colon; multiple locations for a given reading are separated by commas; multiple “location: reading” values are separated by a space. Each location reference is of the form /[0-9]{4}.[0-9]{3}*?/ . The number preceding the period is the page number, zero-padded to four digits. The first two digits of the number following the period are the entry’s position on the page, zero-padded. The third digit is 0 for a main entry and greater than 0 for a parenthesized variant of the main entry. A trailing “*” (asterisk) on the location indicates an encoded variant substituted for an unencoded character (see below). This is an abridged description. For bibliographic information and release notes, see the field entry in Annex #38. Shape of return Notes","ref":"readings.html#kxhc1983","title":"Readings - kXHC1983","type":"extras"},{"doc":"","ref":"variants.html","title":"Variants","type":"extras"},{"doc":"Description The Unicode value for a semantic variant for this character. A semantic variant is an x- or y-variant with similar or identical meaning which can generally be used in place of the indicated character. The basic syntax is a Unicode scalar value. It may optionally be followed by additional data. The additional data is separated from the Unicode scalar value by a less-than sign (&lt;), and may be subdivided itself into substrings by commas, each of which may be divided into two pieces by a colon. The additional data consists of a series of field tags for another field in the Unihan database indicating the source of the information. If these field tags are themselves subdivided by a colon, the final piece is a string consisting of the letters T (for tòng, U+540C 同) B (for bù, U+4E0D 不), Z (for zhèng, U+6B63 正), F (for fán, U+7E41 繁), or J (for jiǎn U+7C21 簡/U+7B80 简). T is used if the indicated source explicitly indicates the two are the same (for example, by saying that the one character is “the same as” the other). B is used if the source explicitly indicates that the two are used improperly one for the other. Z is used if the source explicitly indicates that the given character is the preferred form. Thus, kHanYu indicates that U+5231 刱 and U+5275 創 are semantic variants and that U+5275 創 is the preferred form. F is used if the source explicitly indicates that the given character is the traditional form. J is used if the source explicitly indicates that the given character is the simplified form. Data on simplified and traditional variations can be included in this field to document cases where different sources disagree on the nature of the relationship between two characters. The kSemanticVariant and kSpecializedSemanticVariant fields need not be consulted when interconverting between traditional and simplified Chinese. As an example, U+3A17 has the kSemanticVariant value &quot;U+6377&lt;kHanYu:TZ&quot;. This means that, according to the Hanyu Da Zidian, U+3A17 and U+6377 have identical meaning and that U+6377 is the preferred form. Shape of return Notes","ref":"variants.html#ksemanticvariant","title":"Variants - kSemanticVariant","type":"extras"},{"doc":"Description The Unicode value(s) for the simplified Chinese variant(s) for this character. A full discussion of the kSimplifiedVariant and kTraditionalVariant fields is found in Section 3.7.1 above. Much of the data on simplified and traditional variants was graciously supplied by Wenlin Institute, Inc. http://www.wenlin.com . Shape of return Notes","ref":"variants.html#ksimplifiedvariant","title":"Variants - kSimplifiedVariant","type":"extras"},{"doc":"Description The Unicode value for a specialized semantic variant for this character. The syntax is the same as for the kSemanticVariant field. A specialized semantic variant is an x- or y-variant with similar or identical meaning only in certain contexts. Shape of return Notes","ref":"variants.html#kspecializedsemanticvariant","title":"Variants - kSpecializedSemanticVariant","type":"extras"},{"doc":"Description The spoofing variants for the character, if any. Spoofing variants include character pairs which look similar, particularly at small point sizes, which are not already z-variants or compatibility variants. See Section 3.7.3 for a full description of spoofing variants. The syntax consists of the character's code point. Shape of return Notes","ref":"variants.html#kspoofingvariant","title":"Variants - kSpoofingVariant","type":"extras"},{"doc":"Description The Unicode value(s) for the traditional Chinese variant(s) for this character. A full discussion of the kSimplifiedVariant and kTraditionalVariant fields is found in Section 3.7.1 above. Much of the data on simplified and traditional variants was graciously supplied by Wenlin Institute, Inc. http://www.wenlin.com . Shape of return Notes","ref":"variants.html#ktraditionalvariant","title":"Variants - kTraditionalVariant","type":"extras"},{"doc":"Description The z-variants for the character, if any. Z-variants are instances where the same abstract shape has been encoded multiple times, either in error or because of source separation. Z-variant pairs also have identical semantics. The basic syntax is a Unicode scalar value. It may optionally be followed by additional data. The additional data is separated from the Unicode scalar value by a less-than sign (&lt;), and may be subdivided itself into substrings by commas. The additional data consists of a series of field tags for another field in the Unihan database indicating the source of the information. Shape of return Notes","ref":"variants.html#kzvariant","title":"Variants - kZVariant","type":"extras"}]